<?php declare(strict_types=1);
/**
 * JTL Plugin
 * Copyright (C) 2011 - 2020 Andreas Petermann
 *
 * PHP version 7.2+
 *
 * @copyright css-umsetzung
 * @author Andreas Petermann <info@css-umsetzung.de>
 * @package css_artikel_sort
 * @license GNU
 * @version 1.00
 *
 */

namespace Plugin\css_artikel_sort;

use JTL\Alert\Alert;
use JTL\Catalog\Category\Kategorie;
use JTL\Catalog\Product\Artikel;
use JTL\Events\Dispatcher;
use JTL\Events\Event;
use JTL\Helpers\Form;
use JTL\Helpers\Request;
use JTL\Link\LinkInterface;
use JTL\Plugin\Bootstrapper;
use JTL\Shop;
use JTL\Smarty\JTLSmarty;
use JTL\Minify\MinifyService;
use Plugin\css_artikel_sort\src\cssPlugin;

class Bootstrap extends Bootstrapper
{

    private $cssPlugin;


    /**
     * @inheritdoc
     */
    public function boot(Dispatcher $dispatcher)
    {

        parent::boot($dispatcher);
            $plugin = $this->getPlugin();

        if (Shop::isFrontend() === true || (isset($_REQUEST['kPlugin']) &&  $plugin->getID() == (int) $_REQUEST['kPlugin'])) {

            $this->cssPlugin = src\cssPlugin\cssPlugin::getInstance(
                $plugin,
                $this->getDB(),
                $this->getCache()
            );
        }
        if (Shop::isFrontend() === true) {
            $cfg = $this->cssPlugin->getConfig();
            if($cfg->pluginActive=='N') return;

            $dispatcher->listen('shop.hook.' . \HOOK_PRODUCTFILTER_GET_BASE_QUERY  , function ($args) use ($plugin) {
                $this->cssPlugin->hookProductfilterGetBaseQuery($args);
            });

        }  else {

#            require_once $plugin->getPaths()->getBasePath() . 'includes/defines_inc.php';
#            $this->admin = new Admin($this->getDB(), Shop::Container()->getBackendLogService());
        }

    }        

    /**
     * @inheritdoc
     */
    public function installed()
    {
        $plugin  = $this->getPlugin();
        $minify          = new MinifyService();
        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,CACHING_GROUP_PLUGIN, CACHING_GROUP_TEMPLATE,'cache_'.$plugin->getPluginID()));
        parent::installed();
    }

    /**
     * @inheritdoc
     */
    public function updated($oldVersion, $newVersion)
    {
        $plugin  = $this->getPlugin();
        $minify          = new MinifyService();
        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,CACHING_GROUP_PLUGIN, CACHING_GROUP_TEMPLATE,'cache_'.$plugin->getPluginID()));
        \error_log('updated from ' . $oldVersion . ' to ' . $newVersion);
    }

    /**
     * @inheritdoc
     */
    public function uninstalled(bool $deleteData = true)
    {
        if($deleteData === true) {
            $this->getDB()->query('DROP TABLE IF EXISTS `css_artikel_sortConfig`', 3);
        }
        parent::uninstalled($deleteData);
        $plugin  = $this->getPlugin();
        $minify          = new MinifyService();
        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,CACHING_GROUP_PLUGIN, CACHING_GROUP_TEMPLATE,'cache_'.$plugin->getPluginID()));
    }
}
